package com.ruoyi.dxp.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.dxp.domain.RuleDesensitization;

/**
 * 脱敏规则Service接口
 * 
 * @author jy
 * @date 2022-12-03
 */
public interface IRuleDesensitizationService 
{
    /**
     * 查询脱敏规则
     * 
     * @param id 脱敏规则主键
     * @return 脱敏规则
     */
    public RuleDesensitization selectRuleDesensitizationById(Long id);

    /**
     * 查询脱敏规则列表
     * 
     * @param ruleDesensitization 脱敏规则
     * @return 脱敏规则集合
     */
    public List<RuleDesensitization> selectRuleDesensitizationList(RuleDesensitization ruleDesensitization);

    /**
     * 新增脱敏规则
     * 
     * @param ruleDesensitization 脱敏规则
     * @return 结果
     */
    public int insertRuleDesensitization(RuleDesensitization ruleDesensitization);

    /**
     * 修改脱敏规则
     * 
     * @param ruleDesensitization 脱敏规则
     * @return 结果
     */
    public int updateRuleDesensitization(RuleDesensitization ruleDesensitization);

    /**
     * 批量删除脱敏规则
     * 
     * @param ids 需要删除的脱敏规则主键集合
     * @return 结果
     */
    public int deleteRuleDesensitizationByIds(Long[] ids);

    /**
     * 删除脱敏规则信息
     * 
     * @param id 脱敏规则主键
     * @return 结果
     */
    public AjaxResult deleteRuleDesensitizationById(Long id);

    /**
     * 添加数量
     * @param id id
     * @param type 资源数，项数
     * @param calc add加，mius减
     */
    public void addCount(Long id, String type, String calc);
}
