package com.ruoyi.web.controller.dxp.system.quality;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dxp.domain.RuleDesensitization;
import com.ruoyi.dxp.service.IRuleDesensitizationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 脱敏规则Controller
 * 
 * @author jy
 * @date 2022-12-03
 */
@RestController
@RequestMapping("/system/quality/desensitization")
public class RuleDesensitizationController extends BaseController
{
    @Autowired
    private IRuleDesensitizationService ruleDesensitizationService;

    /**
     * 查询脱敏规则列表
     */
    @PreAuthorize("@ss.hasPermi('system/quality:desensitization:list')")
    @GetMapping("/list")
    public TableDataInfo list(RuleDesensitization ruleDesensitization)
    {
        startPage();
        List<RuleDesensitization> list = ruleDesensitizationService.selectRuleDesensitizationList(ruleDesensitization);
        return getDataTable(list);
    }

    /**
     * 导出脱敏规则列表
     */
    @PreAuthorize("@ss.hasPermi('system/quality:desensitization:export')")
    @Log(title = "脱敏规则", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RuleDesensitization ruleDesensitization)
    {
        List<RuleDesensitization> list = ruleDesensitizationService.selectRuleDesensitizationList(ruleDesensitization);
        ExcelUtil<RuleDesensitization> util = new ExcelUtil<RuleDesensitization>(RuleDesensitization.class);
        util.exportExcel(response, list, "脱敏规则数据");
    }

    /**
     * 获取脱敏规则详细信息
     */
    @PreAuthorize("@ss.hasPermi('system/quality:desensitization:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(ruleDesensitizationService.selectRuleDesensitizationById(id));
    }

    /**
     * 新增脱敏规则
     */
    @PreAuthorize("@ss.hasPermi('system/quality:desensitization:add')")
    @Log(title = "脱敏规则", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RuleDesensitization ruleDesensitization)
    {
        return toAjax(ruleDesensitizationService.insertRuleDesensitization(ruleDesensitization));
    }

    /**
     * 修改脱敏规则
     */
    @PreAuthorize("@ss.hasPermi('system/quality:desensitization:edit')")
    @Log(title = "脱敏规则", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RuleDesensitization ruleDesensitization)
    {
        return toAjax(ruleDesensitizationService.updateRuleDesensitization(ruleDesensitization));
    }

    /**
     * 删除脱敏规则
     */
    @PreAuthorize("@ss.hasPermi('system/quality:desensitization:remove')")
    @Log(title = "脱敏规则", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long ids)
    {
        return ruleDesensitizationService.deleteRuleDesensitizationById(ids);
    }
}
